import {select, arc, 
         geoMercator, 
        geoOrthographic, 
        geoStereographic, 
        geoNaturalEarth1 ,
        scaleOrdinal, 
        schemeCategory10,
        schemeReds} from 'd3';

import {loadAndProcessData} from './loadAndProcessData';
import {colorLegend} from './colorLegend';
import {choroplethMap} from './choroplethMap';

const svg = d3.select("svg");


const g= svg.append('g');
const colorLegendGroup = 
      g.append('g')
		.attr('transform',`translate(20,420)`);

const mapGroup = g.append('g');

const colorScale = scaleOrdinal();

let selectedLegendItem=null;
let features;

//re-render when legend item is clicked
const onClick = d => {
	selectedLegendItem = d;
  //console.log(selectedLegendItem);
  render();
};


const render = () => {
  //console.log(selectedLegendItem);
  

    const colorValue = d => d.properties.income_grp;

    colorScale.domain(features.map(colorValue))
  						.domain(colorScale.domain().filter((d)=>d!=null).sort().reverse()) 
    					.range(schemeReds[colorScale.domain().length]) // range depending on number of categories in the data
    
  
  //console.log(colorScale.domain());
  colorLegendGroup
		.call(colorLegend, {colorScale		 			: colorScale, 
                        circleRadius	 			: 4,
                        legendSpacing  			: 15,
                        textOffset		 			: 10,
                        onClick				 			: onClick,
                        selectedLegendItem 	: selectedLegendItem,
                        legendWidth					: 160
                       });
  
  
	const projection = geoNaturalEarth1(); //geoStereographic(); geoOrthographic(); ...


	

  
}

loadAndProcessData().then(countries=> { 
  features = countries.features;
  render();

} );

/*
World Atlas data (countries-110m.json) is in TopoJSON format.
D3 geo libraries can work with GeoJSON.
Therefore the TopoJSON-data needs to be converted to GeoJSON
in order to generate svg-paths using D3.
This is done with the geoPath-library.

In this script two generator functions are created:
1. projection: generate map projection
2. pathGenerator: convert TopoJSON to GeoJSON, then project it using the projection

*/






